aboutsummaryrefslogtreecommitdiffstats
path: root/cryptography/hazmat/backends/interfaces.py
diff options
context:
space:
mode:
Diffstat (limited to 'cryptography/hazmat/backends/interfaces.py')
-rw-r--r--cryptography/hazmat/backends/interfaces.py5
1 files changed, 3 insertions, 2 deletions
diff --git a/cryptography/hazmat/backends/interfaces.py b/cryptography/hazmat/backends/interfaces.py
index e4e69f10..8d17d3ad 100644
--- a/cryptography/hazmat/backends/interfaces.py
+++ b/cryptography/hazmat/backends/interfaces.py
@@ -99,7 +99,8 @@ class RSABackend(six.with_metaclass(abc.ABCMeta)):
"""
@abc.abstractmethod
- def create_rsa_verify_ctx(self, public_key, signature, padding, algorithm):
+ def create_rsa_verification_ctx(self, public_key, signature, padding, algorithm):
"""
- Returns an object conforming to the AsymmetricVerifyContext interface.
+ Returns an object conforming to the AsymmetricVerificationContext
+ interface.
"""